@@ -121,6 +121,8 @@
 #' plot(gg_dta, panel=TRUE)
 #' }
 #' 
+#' @aliases gg_interaction gg_interaction.randomForest gg_interaction.rfsrc
+#' 
 #' @export 
 gg_interaction <- function (object, ...) {
   UseMethod("gg_interaction", object)
@@ -152,4 +154,9 @@ gg_interaction.rfsrc <- function(object, ...){
 }
 # 
 #' @export
-gg_interaction.default <- gg_interaction.rfsrc
\ No newline at end of file
+gg_interaction.randomForest <- function(object, ...){
+  stop("gg_interaction is not yet support for randomForest objects")
+}
+
+#' @export
+gg_interaction.default <- gg_interaction.rfsrc
