@@ -49,12 +49,9 @@
 #' gg_dta <- gg_roc(rfsrc_iris, which.outcome=3)
 #' plot(gg_dta)
 #' 
-#' # Alternatively, you can plot all three outcomes in one go
-#' # by calling the plot function on the forest object. 
-#' plot(rfsrc_iris)
 #' 
 #' 
-#' @aliases gg_roc
+#' @aliases gg_roc gg_roc.rfsrc gg_roc.randomForest
 
 #' @export 
 gg_roc.rfsrc <- function(object, which.outcome, oob=TRUE, ...){
@@ -87,7 +84,16 @@ gg_roc.rfsrc <- function(object, which.outcome, oob=TRUE, ...){
   invisible(gg_dta)
 }
 #' @export
-# gg_roc <- function (object, which.outcome, oob, ...) {
-#   UseMethod("gg_roc", object)
-# }
-gg_roc <- gg_roc.rfsrc
\ No newline at end of file
+gg_roc <- function (object, which.outcome, oob, ...) {
+  UseMethod("gg_roc", object)
+}
+
+#' @export
+gg_roc.randomForest <-  function(object, ...){
+  stop("gg_roc is not yet support for randomForest objects")
+}
+
+
+
+#' @export
+gg_roc.default <- gg_roc.rfsrc
\ No newline at end of file
